% YF1/FixJ, cI repressor model : https://2019.igem.org/Team:IISER-Pune-India/Model/Mutator-plasmid
% IPTG/LacI model : https://www.sciencedirect.com/science/article/pii/S0006349508001008
function [dxdt] = Model_IPTG_Induction_comp(t,x,p)
% lacI constitutive promotor -> mRNAlacI -> LacI -> LacId(dimer, act as repressor, bind to Lac operator)
%x1 = mRNAlacI
dxdt(1,1) = p.AmR - p.dmR*x(1);
%x2 = LacI
dxdt(2,1) = p.kpR*x(1) - 2*p.k2R*x(2)^2 + 2*p.kn2R*x(3) - p.dpR*x(2);
%x3 = LacId
dxdt(3,1) = p.k2R*x(2)^2 - p.kn2R*x(3) - p.kr*x(3)*x(4) + p.knr*(p.lacOptot-x(4)) - p.kdr1*x(3)*x(5) + p.kndr1*x(6) - p.dpR2*x(3);
%x4 = LacOp
dxdt(4,1) = -p.kr*x(3)*x(4) + p.knr*(p.lacOptot-x(4)) + p.kdr2*(p.lacOptot-x(4))*x(5)^2 - p.kndr2*x(4)*x(6);
%x5 = IPTG
dxdt(5,1) = -2*p.kdr1*x(5)^2*x(3) + 2*p.kndr1*x(6) - 2*p.kdr2*(p.lacOptot-x(4))*x(5)^2 + 2*p.kndr2*x(4)*x(6) + p.kt*(p.IPTGex - x(5)) + 2*p.dI2R2*x(6);
%x6 = IPTG-2_lacI-2
dxdt(6,1) = p.kdr1*x(3)*x(5)^2 - p.kndr1*x(6) + p.kdr2*(p.lacOptot-x(4))*x(5)^2 - p.kndr2*x(4)*x(6) - p.dI2R2*x(6);

%x7 = mRNAB
dxdt(7,1) = p.kmB*0.5*x(4) - p.dmB*x(7);
%x8 = vioB
dxdt(8,1) = p.kpB*x(7) - p.dpB*x(8);
%x9 = mRNAE
dxdt(9,1) = p.kmE*0.5*x(4) - p.dmE*x(9);
%x10 = vioE
dxdt(10,1) = p.kpE*x(9) - p.dpE*x(10);

end


function [y] = MoleculesToMoles(x)
y= x/(6.02*10^23* 1.3*10^(-15));
end

function [y] = MolesToMolecules(x)
y= x*(6.02*10^23* 1.3*10^(-15));
end
