% YF1/FixJ, cI repressor model : https://2019.igem.org/Team:IISER-Pune-India/Model/Mutator-plasmid
% IPTG/LacI model : https://www.sciencedirect.com/science/article/pii/S0006349508001008
% https://openwetware.org/wiki/IGEM:IMPERIAL/2009/M1/Modelling/LacI-IPTG
function [dxdt] = Model_IPTGInduction_simp(t,x,p)
% lacI constitutive promotor -> mRNAlacI -> LacI <-> LacI2(dimer, act as repressor, bind to Lac operator)
% LacI2 + LacOp <-> LacI2_LacOp
% 2IPTG + LacI2 <-> IPTG2_LacI2
% 2IPTG + LacI2_LacOp <-> IPTG2_LacI2 + LacOp
% IPTGex <-> IPTG
% IPTG2_LacI2 -> 2IPTG
%x1 = mRNAlacI
dxdt(1,1) = p.AmR - p.dmR*x(1);
%x2 = LacI
dxdt(2,1) = p.kpR*x(1) - p.kb1*x(2)*x(3) + p.kb2*x(4) - p.dpR*x(2);
%x3 = IPTG
dxdt(3,1) = -p.kb1*x(2)*x(3) + p.kb2*x(4);
%x4 = LacI-IPTG
dxdt(4,1) = p.kb1*x(2)*x(3) -p.kb2*x(4);

% LacI2_LacOp : disabled form
% mRNAB, mRNAE - same amount, half of the LacOp act as input
% 0.5*LacOp -> mRNAB -> Vio-B, 0.5*LacOp -> mRNAE -> mRNAE
%x5 = mRNAB
dxdt(5,1) = p.kmB * (p.Th^p.n3/(p.Th^p.n3 + x(2)^p.n3)) - p.dmB*x(5);
%x6 = vioB
dxdt(6,1) = p.kpB*x(5) - p.dpB*x(6);
%x7 = mRNAE
dxdt(7,1) = p.kmE * (p.Th^p.n3/(p.Th^p.n3 + x(2)^p.n3)) - p.dmE*x(7);
%x8 = vioE
dxdt(8,1) = p.kpE*x(7) - p.dpE*x(8);

end


function [y] = MoleculesToMoles(x)
y= x/(6.02*10^23* 1.3*10^(-15));
end

function [y] = MolesToMolecules(x)
y= x*(6.02*10^23* 1.3*10^(-15));
end
